from . import dataset, metrics, trainers, models, zenodo, plotting, utils, classifiers

__author__ = ', '.join([
    'Marco Wagenstetter',
    'Mohsen Naghipourfar',
    'Mohammad Lotfollahi',
    'Sergei Rybakov'
])

__email__ = ', '.join([
    'marco.wagenstetter@tum.de',
    'naghipourfar@ce.sharif.edu',
    'mohammad.lotfollahi@helmholtz-muenchen.de',
    'sergei.rybakov@helmholtz-muenchen.de'
])

__version__ = '0.5.4'
